# eric7.EricGui

Package implementing some special GUI elements.

They extend or amend the standard elements as found in QtGui.

### Modules

EricAction | Module implementing an Action class extending QAction.
EricGenericDiffHighlighter | Module implementing a syntax highlighter for diff outputs.
EricOverrideCursor | Module implementing a context manager class for an override cursor and a QProcess class controlling an override cursor.